'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.verifyExists = verifyExists;
exports.findRecursive = findRecursive;
exports.getUserHome = getUserHome;
exports.findConfigFilePath = findConfigFilePath;
exports.createFile = createFile;

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _mkdirp = require('mkdirp');

var _mkdirp2 = _interopRequireDefault(_mkdirp);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function verifyExists(fullPath) {
    if (_fs2.default.existsSync(fullPath)) {
        return fullPath;
    } else if (_fs2.default.existsSync(fullPath + '.json')) {
        return fullPath + '.json';
    } else if (_fs2.default.existsSync(fullPath + '.cson')) {
        return fullPath + '.cson';
    }
    return false;
}

function findRecursive(dir, fileName) {
    var fullPath = _path2.default.join(dir, fileName);
    var nextDir = _path2.default.dirname(dir);
    var result = verifyExists(fullPath);

    if (!result && nextDir !== dir) {
        result = findRecursive(nextDir, fileName);
    }

    return result;
}

function getUserHome() {
    return process.env.HOME || process.env.USERPROFILE || "";
}

function findConfigFilePath(dir, filename) {
    var configPath = findRecursive(dir, filename);

    if (!configPath) {
        var inHomePath = verifyExists(_path2.default.join(getUserHome(), filename));
        if (inHomePath) {
            configPath = inHomePath;
        }
    }

    return configPath;
}

function createFile(filePath, content) {
    _mkdirp2.default.sync(_path2.default.dirname(filePath));

    if (!_fs2.default.existsSync(filePath)) {
        _fs2.default.writeFileSync(filePath, content);
    }
}